function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);
  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }
  return keys;
}
function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      _defineProperty(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }
  return target;
}
function _typeof(obj) {
  "@babel/helpers - typeof";

  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
    return typeof obj;
  } : function (obj) {
    return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
  }, _typeof(obj);
}
function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}

function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
function get_current_component() {
    if (!current_component)
        throw new Error('Function called outside component initialization');
    return current_component;
}
/**
 * The `onMount` function schedules a callback to run as soon as the component has been mounted to the DOM.
 * It must be called during the component's initialisation (but doesn't need to live *inside* the component;
 * it can be called from an external module).
 *
 * `onMount` does not run inside a [server-side component](/docs#run-time-server-side-component-api).
 *
 * https://svelte.dev/docs#run-time-svelte-onmount
 */
function onMount(fn) {
    get_current_component().$$.on_mount.push(fn);
}
/**
 * Schedules a callback to run immediately before the component is unmounted.
 *
 * Out of `onMount`, `beforeUpdate`, `afterUpdate` and `onDestroy`, this is the
 * only one that runs inside a server-side component.
 *
 * https://svelte.dev/docs#run-time-svelte-ondestroy
 */
function onDestroy(fn) {
    get_current_component().$$.on_destroy.push(fn);
}
const ATTR_REGEX = /[&"]/g;
const CONTENT_REGEX = /[&<]/g;
/**
 * Note: this method is performance sensitive and has been optimized
 * https://github.com/sveltejs/svelte/pull/5701
 */
function escape(value, is_attr = false) {
    const str = String(value);
    const pattern = is_attr ? ATTR_REGEX : CONTENT_REGEX;
    pattern.lastIndex = 0;
    let escaped = '';
    let last = 0;
    while (pattern.test(str)) {
        const i = pattern.lastIndex - 1;
        const ch = str[i];
        escaped += str.substring(last, i) + (ch === '&' ? '&amp;' : (ch === '"' ? '&quot;' : '&lt;'));
        last = i + 1;
    }
    return escaped + str.substring(last);
}
let on_destroy;
function create_ssr_component(fn) {
    function $$render(result, props, bindings, slots, context) {
        const parent_component = current_component;
        const $$ = {
            on_destroy,
            context: new Map(context || (parent_component ? parent_component.$$.context : [])),
            // these will be immediately discarded
            on_mount: [],
            before_update: [],
            after_update: [],
            callbacks: blank_object()
        };
        set_current_component({ $$ });
        const html = fn(result, props, bindings, slots);
        set_current_component(parent_component);
        return html;
    }
    return {
        render: (props = {}, { $$slots = {}, context = new Map() } = {}) => {
            on_destroy = [];
            const result = { title: '', head: '', css: new Set() };
            const html = $$render(result, props, {}, $$slots, context);
            run_all(on_destroy);
            return {
                html,
                css: {
                    code: Array.from(result.css).map(css => css.code).join('\n'),
                    map: null // TODO
                },
                head: result.title + result.head
            };
        },
        $$render
    };
}
function add_attribute(name, value, boolean) {
    if (value == null || (boolean && !value))
        return '';
    const assignment = (boolean && value === true) ? '' : `="${escape(value, true)}"`;
    return ` ${name}${assignment}`;
}

var isElementInViewport = function isElementInViewport(element) {
  var container = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  var position = arguments.length > 2 ? arguments[2] : undefined;
  var rect = element.getBoundingClientRect();
  var viewportWidth = window.innerWidth || document.documentElement.clientWidth;
  var viewportHeight = window.innerHeight || document.documentElement.clientHeight;
  var isInsideViewport = rect.bottom > 0 && rect.top < viewportHeight && rect.right > 0 && rect.left < viewportWidth;
  if (container) {
    var containerRect = container.getBoundingClientRect();
    if (position === 'top' || position === 'bottom') {
      isInsideViewport = containerRect.bottom + containerRect.height < viewportHeight && containerRect.top < viewportHeight;
    } else {
      isInsideViewport = containerRect.right + containerRect.width < viewportWidth && containerRect.left < viewportWidth;
    }
    return isInsideViewport;
  }
  return isInsideViewport;
};
var computeTooltipPosition = function computeTooltipPosition(containerRef, tooltipRef, position, coords) {
  if (!containerRef || !tooltipRef) {
    return coords;
  }
  var containerRect = containerRef.getBoundingClientRect();
  var tooltipRect = tooltipRef.getBoundingClientRect();
  switch (position) {
    case 'top':
      coords.top = containerRect.top;
      coords.left = containerRect.left + containerRect.width / 2;
      break;
    case 'bottom':
      coords.top = containerRect.top - tooltipRect.height;
      coords.left = containerRect.left + containerRect.width / 2;
      break;
    case 'left':
      coords.left = containerRect.left;
      coords.top = containerRect.top + containerRect.height / 2;
      break;
    case 'right':
      coords.left = containerRect.right - tooltipRect.width;
      coords.top = containerRect.top + containerRect.height / 2;
      break;
  }
  coords.top += window.scrollY;
  coords.left += window.scrollX;
  return coords;
};

var inverse = {
  left: 'right',
  right: 'left',
  top: 'bottom',
  bottom: 'top'
};

var css$1 = {
  code: ":root{--tooltip-arrow-size:10px;--tooltip-background-color:rgba(0, 0, 0, 0.9);--tooltip-border-radius:4px;--tooltip-box-shadow:0 1px 20px rgba(0, 0, 0, 0.25);--tooltip-font-family:-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\n      'Helvetica Neue', sans-serif;--tooltip-font-size:14px;--tooltip-font-weight:500;--tooltip-line-height:1.25rem;--tooltip-color:#fff;--tooltip-offset-x:0px;--tooltip-offset-y:0px;--tooltip-padding:12px;--tooltip-pointer-events:none;--tooltip-white-space-hidden:nowrap;--tooltip-white-space-shown:normal;--tooltip-z-index:100}.tooltip.svelte-1fqbu6l{background-color:var(--tooltip-background-color);box-shadow:var(--tooltip-box-shadow);border-radius:var(--tooltip-border-radius);color:var(--tooltip-color);opacity:0;font-family:var(--tooltip-font-family);font-size:var(--tooltip-font-size);font-style:normal;font-weight:var(--tooltip-font-weight);line-height:var(--tooltip-line-height);padding:var(--tooltip-padding);pointer-events:var(--tooltip-pointer-events);position:absolute;text-align:left;visibility:hidden;white-space:var(--tooltip-white-space-hidden);z-index:var(--tooltip-z-index)}.tooltip.show.svelte-1fqbu6l{opacity:1;visibility:visible;white-space:var(--tooltip-white-space-shown)}.tooltip.bottom.svelte-1fqbu6l:after,.tooltip.left.svelte-1fqbu6l:after,.tooltip.right.svelte-1fqbu6l:after,.tooltip.top.svelte-1fqbu6l:after{border:var(--tooltip-arrow-size) solid var(--tooltip-background-color);content:' ';position:absolute}.tooltip.arrowless.svelte-1fqbu6l:after{border:0 !important}.tooltip.bottom.svelte-1fqbu6l,.tooltip.top.svelte-1fqbu6l{--tooltip-offset-x:0px;--tooltip-offset-y:12px}.tooltip.left.svelte-1fqbu6l,.tooltip.right.svelte-1fqbu6l{--tooltip-offset-x:12px;--tooltip-offset-y:0px}.tooltip.bottom.svelte-1fqbu6l{bottom:0;left:50%;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    )}.tooltip.bottom.svelte-1fqbu6l:after{border-color:transparent transparent var(--tooltip-background-color);left:50%;top:0;transform:translate(-50%, -99%)}.tooltip.top.svelte-1fqbu6l{left:50%;top:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    )}.tooltip.top.svelte-1fqbu6l:after{border-color:var(--tooltip-background-color) transparent transparent transparent;bottom:0;left:50%;transform:translate(-50%, 99%)}.tooltip.left.svelte-1fqbu6l{left:0;top:50%;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    )}.tooltip.left.svelte-1fqbu6l:after{border-color:transparent transparent transparent var(--tooltip-background-color);right:0;top:50%;transform:translate(99%, -50%)}.tooltip.right.svelte-1fqbu6l{right:0;top:50%;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    )}.tooltip.right.svelte-1fqbu6l:after{border-color:transparent var(--tooltip-background-color) transparent transparent;left:0;top:50%;transform:translate(-99%, -50%)}.tooltip.animation-fade.svelte-1fqbu6l{opacity:0;transition:opacity 0.25s ease-in-out}.tooltip.animation-fade.show.svelte-1fqbu6l{opacity:1}.tooltip.top.animation-slide.svelte-1fqbu6l{margin-top:10px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.top.animation-slide.show.svelte-1fqbu6l{margin-top:0;opacity:1}.tooltip.bottom.animation-slide.svelte-1fqbu6l{margin-bottom:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.bottom.animation-slide.show.svelte-1fqbu6l{margin-bottom:0;opacity:1}.tooltip.right.animation-slide.svelte-1fqbu6l{margin-right:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.right.animation-slide.show.svelte-1fqbu6l{margin-right:0;opacity:1}.tooltip.left.animation-slide.svelte-1fqbu6l{margin-left:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.left.animation-slide.show.svelte-1fqbu6l{margin-left:0;opacity:1}.tooltip.left.animation-puff.svelte-1fqbu6l{filter:blur(2px);opacity:0;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.left.animation-puff.show.svelte-1fqbu6l{filter:blur(0);opacity:1;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.right.animation-puff.svelte-1fqbu6l{filter:blur(2px);opacity:0;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.right.animation-puff.show.svelte-1fqbu6l{filter:blur(0);opacity:1;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.top.animation-puff.svelte-1fqbu6l{filter:blur(2px);opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.top.animation-puff.show.svelte-1fqbu6l{filter:blur(0);opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.bottom.animation-puff.svelte-1fqbu6l{filter:blur(2px);opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.bottom.animation-puff.show.svelte-1fqbu6l{filter:blur(0);opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.left.animation-bounce.svelte-1fqbu6l{opacity:0;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% + var(--tooltip-offset-y))\n    ) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.left.animation-bounce.show.svelte-1fqbu6l{opacity:1;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% + var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.right.animation-bounce.svelte-1fqbu6l{opacity:0;transform:translate(calc(100% + var(--tooltip-offset-x)), calc(-50% + var(--tooltip-offset-y))) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.right.animation-bounce.show.svelte-1fqbu6l{opacity:1;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% + var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.top.animation-bounce.svelte-1fqbu6l{opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.top.animation-bounce.show.svelte-1fqbu6l{opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.bottom.animation-bounce.svelte-1fqbu6l{opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.bottom.animation-bounce.show.svelte-1fqbu6l{opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(1, 1)}",
  map: "{\"version\":3,\"file\":\"tooltip.svelte\",\"sources\":[\"tooltip.svelte\"],\"sourcesContent\":[\"<script>\\n  // @ts-check\\n\\n  import { onMount, onDestroy } from 'svelte';\\n  import { computeTooltipPosition, formatVariableKey, getMinWidth, isElementInViewport } from './helpers';\\n  import { inverse } from './constants';\\n\\n  /** @type {'hover' | 'click' | 'prop' | string} */\\n  export let action = 'hover';\\n\\n  /** @type {string | {component: any, props?: Record<string, any>}} */\\n  export let content = '';\\n\\n  /** @type {'left' | 'center' | 'right' | string} */\\n  export let align = 'left';\\n\\n  /** @type {'top' | 'bottom' | 'left' | 'right' | string} */\\n  export let position = 'top';\\n\\n  /** @type {number} */\\n  export let maxWidth = 200;\\n\\n  /** @type {{ [x: string]: any; } | null} */\\n  export let style = null;\\n\\n  /** @type {string} */\\n  export let theme = '';\\n\\n  /** @type {string} */\\n  export let animation = '';\\n\\n  /** @type {boolean} */\\n  export let arrow = true;\\n\\n  /** @type {boolean} */\\n  export let autoPosition = false;\\n\\n  /** @type {boolean} */\\n  export let show = false;\\n\\n  /** @type {HTMLSpanElement | null} */\\n  let containerRef = null;\\n\\n  /** @type {HTMLDivElement | null} */\\n  let tooltipRef = null;\\n\\n  /** @type {number} */\\n  let minWidth = 0;\\n\\n  /** @type {{ $destroy: () => void; } | null} */\\n  let component = null;\\n\\n  /** @type {'top' | string} */\\n  let initialPosition = position;\\n\\n  /** @type {string | null} */\\n  let animationEffect = null;\\n\\n  /** @type {number | null} */\\n  let timer = null;\\n\\n  /** @type {boolean} */\\n  let visible = false;\\n\\n  /** @type {{ bottom: number, top: number, right: number, left: number }} */\\n  let coords = {\\n    bottom: 0,\\n    top: 0,\\n    right: 0,\\n    left: 0\\n  };\\n\\n  const onClick = () => {\\n    if (visible) {\\n      onHide();\\n    } else {\\n      onShow();\\n    }\\n  };\\n\\n  const onShow = () => {\\n    const delay = animation ? 200 : 0;\\n\\n    // @ts-ignore\\n    if (autoPosition && !isElementInViewport(containerRef, tooltipRef, position)) {\\n      // @ts-ignore\\n      position = inverse[position];\\n    }\\n\\n    coords = computeTooltipPosition(containerRef, tooltipRef, position, coords);\\n\\n    if (animation) {\\n      animationEffect = animation;\\n    }\\n\\n    timer = setTimeout(() => (visible = true), delay);\\n  };\\n\\n  const onHide = () => {\\n    visible = false;\\n    position = initialPosition;\\n    animationEffect = null;\\n\\n    if (timer) {\\n      clearTimeout(timer);\\n      timer = null;\\n    }\\n  };\\n\\n  const addListeners = () => {\\n    if (containerRef !== null) {\\n      removeListeners();\\n\\n      if (action === 'click') {\\n        containerRef.addEventListener('click', onClick);\\n      }\\n\\n      if (action === 'hover') {\\n        containerRef.addEventListener('mouseenter', onShow);\\n        containerRef.addEventListener('mouseleave', onHide);\\n      }\\n    }\\n  }\\n\\n  const removeListeners = () => {\\n    if (containerRef !== null) {\\n      containerRef.removeEventListener('click', onClick);\\n      containerRef.removeEventListener('mouseenter', onShow);\\n      containerRef.removeEventListener('mouseleave', onHide);\\n    }\\n  };\\n\\n  onMount(() => {\\n    addListeners();\\n\\n    computeTooltipPosition();\\n\\n    if (tooltipRef !== null) {\\n      if (isComponent && !component) {\\n        // @ts-ignore\\n        component = new content.component({\\n          target: tooltipRef,\\n          // @ts-ignore\\n          props: content.props\\n        });\\n      }\\n\\n      minWidth = getMinWidth(tooltipRef, maxWidth);\\n\\n      if (style && typeof style === 'object') {\\n        for (let prop in style) {\\n          const key = formatVariableKey(prop);\\n          const value = style[prop];\\n\\n          tooltipRef.style.setProperty(`--tooltip-${key}`, value);\\n        }\\n      }\\n    }\\n  });\\n\\n  onDestroy(() => {\\n    if (component) {\\n      component.$destroy();\\n      component = null;\\n    }\\n\\n    removeListeners();\\n  });\\n\\n  $: isComponent = typeof content === 'object';\\n  $: action, addListeners();\\n  $: tooltipRef && show ? onShow() : onHide();\\n</script>\\n\\n{#if content}\\n  <span bind:this={containerRef} class=\\\"tooltip-container\\\">\\n    <slot />\\n  </span>\\n  <div\\n    bind:this={tooltipRef}\\n    class=\\\"tooltip animation-{animationEffect} {position} {theme}\\\"\\n    class:arrowless={!arrow}\\n    class:show={visible}\\n    style=\\\"bottom: auto; right: auto; left: {coords.left}px; min-width: {minWidth}px; max-width: {maxWidth}px; text-align: {align}; top: {coords.top}px;\\\">\\n    {#if !isComponent}\\n      {@html content}\\n    {/if}\\n  </div>\\n{:else}\\n  <slot />\\n{/if}\\n\\n<style>\\n  /*--------------------------*\\n   * Theme Variables\\n   *--------------------------*/\\n\\n  :root {\\n    --tooltip-arrow-size: 10px;\\n    --tooltip-background-color: rgba(0, 0, 0, 0.9);\\n    --tooltip-border-radius: 4px;\\n    --tooltip-box-shadow: 0 1px 20px rgba(0, 0, 0, 0.25);\\n    --tooltip-font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\\n      'Helvetica Neue', sans-serif;\\n    --tooltip-font-size: 14px;\\n    --tooltip-font-weight: 500;\\n    --tooltip-line-height: 1.25rem;\\n    --tooltip-color: #fff;\\n    --tooltip-offset-x: 0px;\\n    --tooltip-offset-y: 0px;\\n    --tooltip-padding: 12px;\\n    --tooltip-pointer-events: none;\\n    --tooltip-white-space-hidden: nowrap;\\n    --tooltip-white-space-shown: normal;\\n    --tooltip-z-index: 100;\\n  }\\n\\n  /*--------------------------*\\n   * Tooltip Styling\\n   *--------------------------*/\\n\\n  .tooltip {\\n    background-color: var(--tooltip-background-color);\\n    box-shadow: var(--tooltip-box-shadow);\\n    border-radius: var(--tooltip-border-radius);\\n    color: var(--tooltip-color);\\n    opacity: 0;\\n    font-family: var(--tooltip-font-family);\\n    font-size: var(--tooltip-font-size);\\n    font-style: normal;\\n    font-weight: var(--tooltip-font-weight);\\n    line-height: var(--tooltip-line-height);\\n    padding: var(--tooltip-padding);\\n    pointer-events: var(--tooltip-pointer-events);\\n    position: absolute;\\n    text-align: left;\\n    visibility: hidden;\\n    white-space: var(--tooltip-white-space-hidden);\\n    z-index: var(--tooltip-z-index);\\n  }\\n\\n  .tooltip.show {\\n    opacity: 1;\\n    visibility: visible;\\n    white-space: var(--tooltip-white-space-shown);\\n  }\\n\\n  .tooltip.bottom:after,\\n  .tooltip.left:after,\\n  .tooltip.right:after,\\n  .tooltip.top:after {\\n    border: var(--tooltip-arrow-size) solid var(--tooltip-background-color);\\n    content: ' ';\\n    position: absolute;\\n  }\\n\\n  .tooltip.arrowless:after {\\n    border: 0 !important;\\n  }\\n\\n .tooltip.bottom,\\n  .tooltip.top {\\n    --tooltip-offset-x: 0px;\\n    --tooltip-offset-y: 12px;\\n  }\\n\\n  .tooltip.left,\\n  .tooltip.right {\\n    --tooltip-offset-x: 12px;\\n    --tooltip-offset-y: 0px;\\n  }\\n\\n  .tooltip.bottom {\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.bottom:after {\\n    border-color: transparent transparent var(--tooltip-background-color);\\n    left: 50%;\\n    top: 0;\\n    transform: translate(-50%, -99%);\\n  }\\n\\n  .tooltip.top {\\n    left: 50%;\\n    top: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.top:after {\\n    border-color: var(--tooltip-background-color) transparent transparent transparent;\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(-50%, 99%);\\n  }\\n\\n  .tooltip.left {\\n    left: 0;\\n    top: 50%;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.left:after {\\n    border-color: transparent transparent transparent var(--tooltip-background-color);\\n    right: 0;\\n    top: 50%;\\n    transform: translate(99%, -50%);\\n  }\\n\\n  .tooltip.right {\\n    right: 0;\\n    top: 50%;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.right:after {\\n    border-color: transparent var(--tooltip-background-color) transparent transparent;\\n    left: 0;\\n    top: 50%;\\n    transform: translate(-99%, -50%);\\n  }\\n\\n  /*--------------------------*\\n   * CSS Animations\\n   *--------------------------*/\\n\\n  /* Fade */\\n\\n  .tooltip.animation-fade {\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.animation-fade.show {\\n    opacity: 1;\\n  }\\n\\n  /* Slide */\\n\\n  .tooltip.top.animation-slide {\\n    margin-top: 10px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-slide.show {\\n    margin-top: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.bottom.animation-slide {\\n    margin-bottom: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-slide.show {\\n    margin-bottom: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.right.animation-slide {\\n    margin-right: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-slide.show {\\n    margin-right: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.left.animation-slide {\\n    margin-left: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-slide.show {\\n    margin-left: 0;\\n    opacity: 1;\\n  }\\n\\n  /* Puff */\\n\\n  .tooltip.left.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  /* Bounce */\\n\\n  .tooltip.left.animation-bounce {\\n    opacity: 0;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% + var(--tooltip-offset-y))\\n    ) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.left.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-bounce {\\n    opacity: 0;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), calc(-50% + var(--tooltip-offset-y))) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.right.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-bounce {\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.top.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-bounce {\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.bottom.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n</style>\\n\"],\"names\":[],\"mappings\":\"AAqME,KAAM,CACJ,oBAAoB,CAAE,IAAI,CAC1B,0BAA0B,CAAE,kBAAkB,CAC9C,uBAAuB,CAAE,GAAG,CAC5B,oBAAoB,CAAE,8BAA8B,CACpD,qBAAqB,CAAE;AAC3B,kCAAkC,CAC9B,mBAAmB,CAAE,IAAI,CACzB,qBAAqB,CAAE,GAAG,CAC1B,qBAAqB,CAAE,OAAO,CAC9B,eAAe,CAAE,IAAI,CACrB,kBAAkB,CAAE,GAAG,CACvB,kBAAkB,CAAE,GAAG,CACvB,iBAAiB,CAAE,IAAI,CACvB,wBAAwB,CAAE,IAAI,CAC9B,4BAA4B,CAAE,MAAM,CACpC,2BAA2B,CAAE,MAAM,CACnC,iBAAiB,CAAE,GACrB,CAMA,uBAAS,CACP,gBAAgB,CAAE,IAAI,0BAA0B,CAAC,CACjD,UAAU,CAAE,IAAI,oBAAoB,CAAC,CACrC,aAAa,CAAE,IAAI,uBAAuB,CAAC,CAC3C,KAAK,CAAE,IAAI,eAAe,CAAC,CAC3B,OAAO,CAAE,CAAC,CACV,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,SAAS,CAAE,IAAI,mBAAmB,CAAC,CACnC,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,OAAO,CAAE,IAAI,iBAAiB,CAAC,CAC/B,cAAc,CAAE,IAAI,wBAAwB,CAAC,CAC7C,QAAQ,CAAE,QAAQ,CAClB,UAAU,CAAE,IAAI,CAChB,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,IAAI,4BAA4B,CAAC,CAC9C,OAAO,CAAE,IAAI,iBAAiB,CAChC,CAEA,QAAQ,oBAAM,CACZ,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CACnB,WAAW,CAAE,IAAI,2BAA2B,CAC9C,CAEA,QAAQ,sBAAO,MAAM,CACrB,QAAQ,oBAAK,MAAM,CACnB,QAAQ,qBAAM,MAAM,CACpB,QAAQ,mBAAI,MAAO,CACjB,MAAM,CAAE,IAAI,oBAAoB,CAAC,CAAC,KAAK,CAAC,IAAI,0BAA0B,CAAC,CACvE,OAAO,CAAE,GAAG,CACZ,QAAQ,CAAE,QACZ,CAEA,QAAQ,yBAAU,MAAO,CACvB,MAAM,CAAE,CAAC,CAAC,UACZ,CAED,QAAQ,sBAAO,CACd,QAAQ,mBAAK,CACX,kBAAkB,CAAE,GAAG,CACvB,kBAAkB,CAAE,IACtB,CAEA,QAAQ,oBAAK,CACb,QAAQ,qBAAO,CACb,kBAAkB,CAAE,IAAI,CACxB,kBAAkB,CAAE,GACtB,CAEA,QAAQ,sBAAQ,CACd,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KACE,CAEA,QAAQ,sBAAO,MAAO,CACpB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACrE,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CACjC,CAEA,QAAQ,mBAAK,CACX,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KACE,CAEA,QAAQ,mBAAI,MAAO,CACjB,YAAY,CAAE,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CAAC,WAAW,CACjF,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,GAAG,CAChC,CAEA,QAAQ,oBAAM,CACZ,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KACE,CAEA,QAAQ,oBAAK,MAAO,CAClB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACjF,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,GAAG,CAAC,CAAC,IAAI,CAChC,CAEA,QAAQ,qBAAO,CACb,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KACE,CAEA,QAAQ,qBAAM,MAAO,CACnB,YAAY,CAAE,WAAW,CAAC,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CACjF,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CACjC,CAQA,QAAQ,8BAAgB,CACtB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAC5B,CAEA,QAAQ,eAAe,oBAAM,CAC3B,OAAO,CAAE,CACX,CAIA,QAAQ,IAAI,+BAAiB,CAC3B,UAAU,CAAE,IAAI,CAChB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,IAAI,gBAAgB,oBAAM,CAChC,UAAU,CAAE,CAAC,CACb,OAAO,CAAE,CACX,CAEA,QAAQ,OAAO,+BAAiB,CAC9B,aAAa,CAAE,IAAI,CACnB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,OAAO,gBAAgB,oBAAM,CACnC,aAAa,CAAE,CAAC,CAChB,OAAO,CAAE,CACX,CAEA,QAAQ,MAAM,+BAAiB,CAC7B,YAAY,CAAE,IAAI,CAClB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,MAAM,gBAAgB,oBAAM,CAClC,YAAY,CAAE,CAAC,CACf,OAAO,CAAE,CACX,CAEA,QAAQ,KAAK,+BAAiB,CAC5B,WAAW,CAAE,IAAI,CACjB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,KAAK,gBAAgB,oBAAM,CACjC,WAAW,CAAE,CAAC,CACd,OAAO,CAAE,CACX,CAIA,QAAQ,KAAK,8BAAgB,CAC3B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,KAAK,eAAe,oBAAM,CAChC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,MAAM,8BAAgB,CAC5B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,MAAM,eAAe,oBAAM,CACjC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,IAAI,8BAAgB,CAC1B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,IAAI,eAAe,oBAAM,CAC/B,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,OAAO,8BAAgB,CAC7B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,OAAO,eAAe,oBAAM,CAClC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAIA,QAAQ,KAAK,gCAAkB,CAC7B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjB,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,KAAK,iBAAiB,oBAAM,CAClC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,MAAM,gCAAkB,CAC9B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CAChH,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,MAAM,iBAAiB,oBAAM,CACnC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,IAAI,gCAAkB,CAC5B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjB,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,IAAI,iBAAiB,oBAAM,CACjC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,OAAO,gCAAkB,CAC/B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjB,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,OAAO,iBAAiB,oBAAM,CACpC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd\"}"
};
var Tooltip$1 = create_ssr_component(function ($$result, $$props, $$bindings, slots) {
  var isComponent;
  var _$$props$action = $$props.action,
    action = _$$props$action === void 0 ? 'hover' : _$$props$action;
  var _$$props$content = $$props.content,
    content = _$$props$content === void 0 ? '' : _$$props$content;
  var _$$props$align = $$props.align,
    align = _$$props$align === void 0 ? 'left' : _$$props$align;
  var _$$props$position = $$props.position,
    position = _$$props$position === void 0 ? 'top' : _$$props$position;
  var _$$props$maxWidth = $$props.maxWidth,
    maxWidth = _$$props$maxWidth === void 0 ? 200 : _$$props$maxWidth;
  var _$$props$style = $$props.style,
    style = _$$props$style === void 0 ? null : _$$props$style;
  var _$$props$theme = $$props.theme,
    theme = _$$props$theme === void 0 ? '' : _$$props$theme;
  var _$$props$animation = $$props.animation,
    animation = _$$props$animation === void 0 ? '' : _$$props$animation;
  var _$$props$arrow = $$props.arrow,
    arrow = _$$props$arrow === void 0 ? true : _$$props$arrow;
  var _$$props$autoPosition = $$props.autoPosition,
    autoPosition = _$$props$autoPosition === void 0 ? false : _$$props$autoPosition;
  var _$$props$show = $$props.show,
    show = _$$props$show === void 0 ? false : _$$props$show;

  /** @type {HTMLSpanElement | null} */
  var containerRef = null;

  /** @type {HTMLDivElement | null} */
  var tooltipRef = null;

  /** @type {number} */
  var minWidth = 0;

  /** @type {'top' | string} */
  var initialPosition = position;

  /** @type {string | null} */
  var animationEffect = null;

  /** @type {boolean} */
  var visible = false;

  /** @type {{ bottom: number, top: number, right: number, left: number }} */
  var coords = {
    bottom: 0,
    top: 0,
    right: 0,
    left: 0
  };
  var onHide = function onHide() {
    visible = false;
    position = initialPosition;
    animationEffect = null;
  };
  onMount(function () {
    computeTooltipPosition();
  });
  onDestroy(function () {
  });
  if ($$props.action === void 0 && $$bindings.action && action !== void 0) $$bindings.action(action);
  if ($$props.content === void 0 && $$bindings.content && content !== void 0) $$bindings.content(content);
  if ($$props.align === void 0 && $$bindings.align && align !== void 0) $$bindings.align(align);
  if ($$props.position === void 0 && $$bindings.position && position !== void 0) $$bindings.position(position);
  if ($$props.maxWidth === void 0 && $$bindings.maxWidth && maxWidth !== void 0) $$bindings.maxWidth(maxWidth);
  if ($$props.style === void 0 && $$bindings.style && style !== void 0) $$bindings.style(style);
  if ($$props.theme === void 0 && $$bindings.theme && theme !== void 0) $$bindings.theme(theme);
  if ($$props.animation === void 0 && $$bindings.animation && animation !== void 0) $$bindings.animation(animation);
  if ($$props.arrow === void 0 && $$bindings.arrow && arrow !== void 0) $$bindings.arrow(arrow);
  if ($$props.autoPosition === void 0 && $$bindings.autoPosition && autoPosition !== void 0) $$bindings.autoPosition(autoPosition);
  if ($$props.show === void 0 && $$bindings.show && show !== void 0) $$bindings.show(show);
  $$result.css.add(css$1);
  isComponent = _typeof(content) === 'object';
  {
    onHide();
  }
  return "".concat(content ? "<span class=\"tooltip-container\"".concat(add_attribute("this", containerRef, 0), ">").concat(slots["default"] ? slots["default"]({}) : "", "</span>\n  <div class=\"").concat(["tooltip animation-" + escape(animationEffect, true) + " " + escape(position, true) + " " + escape(theme, true) + " svelte-1fqbu6l", (!arrow ? "arrowless" : "") + ' ' + (visible ? "show" : "")].join(' ').trim(), "\" style=\"").concat("bottom: auto; right: auto; left: " + escape(coords.left, true) + "px; min-width: " + escape(minWidth, true) + "px; max-width: " + escape(maxWidth, true) + "px; text-align: " + escape(align, true) + "; top: " + escape(coords.top, true) + "px;", "\"").concat(add_attribute("this", tooltipRef, 0), ">").concat(!isComponent ? "".concat(content) : "", "</div>") : "".concat(slots["default"] ? slots["default"]({}) : ""));
});
var Tooltip$2 = Tooltip$1;

var css = {
  code: ":root{--tooltip-arrow-size:10px;--tooltip-background-color:rgba(0, 0, 0, 0.9);--tooltip-border-radius:4px;--tooltip-box-shadow:0 1px 20px rgba(0, 0, 0, 0.25);--tooltip-font-family:-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\n      'Helvetica Neue', sans-serif;--tooltip-font-size:14px;--tooltip-font-weight:500;--tooltip-line-height:1.25rem;--tooltip-color:#fff;--tooltip-offset-x:12px;--tooltip-offset-y:12px;--tooltip-padding:12px;--tooltip-pointer-events:none;--tooltip-white-space-hidden:nowrap;--tooltip-white-space-shown:normal;--tooltip-z-index:100}.tooltip.svelte-hla1ha{background-color:var(--tooltip-background-color);box-shadow:var(--tooltip-box-shadow);border-radius:var(--tooltip-border-radius);color:var(--tooltip-color);opacity:0;font-family:var(--tooltip-font-family);font-size:var(--tooltip-font-size);font-style:normal;font-weight:var(--tooltip-font-weight);line-height:var(--tooltip-line-height);padding:var(--tooltip-padding);pointer-events:var(---tooltip-pointer-events);position:absolute;text-align:left;visibility:hidden;white-space:var(--tooltip-white-space-hidden);z-index:var(--tooltip-z-index)}.tooltip.show.svelte-hla1ha{opacity:1;visibility:visible;white-space:var(--tooltip-white-space-shown)}.tooltip.bottom.svelte-hla1ha:after,.tooltip.left.svelte-hla1ha:after,.tooltip.right.svelte-hla1ha:after,.tooltip.top.svelte-hla1ha:after{border:var(--tooltip-arrow-size) solid var(--tooltip-background-color);content:' ';position:absolute}.tooltip.arrowless.svelte-hla1ha:after{border:0 !important}.tooltip.bottom.svelte-hla1ha,.tooltip.top.svelte-hla1ha{--tooltip-offset-x:0px;--tooltip-offset-y:12px}.tooltip.left.svelte-hla1ha,.tooltip.right.svelte-hla1ha{--tooltip-offset-x:12px;--tooltip-offset-y:0px}.tooltip.bottom.svelte-hla1ha{bottom:0;left:50%;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    )}.tooltip.bottom.svelte-hla1ha:after{border-color:transparent transparent var(--tooltip-background-color);left:50%;top:0;transform:translate(-50%, -99%)}.tooltip.top.svelte-hla1ha{left:50%;top:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    )}.tooltip.top.svelte-hla1ha:after{border-color:var(--tooltip-background-color) transparent transparent transparent;bottom:0;left:50%;transform:translate(-50%, 99%)}.tooltip.left.svelte-hla1ha{left:0;top:50%;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    )}.tooltip.left.svelte-hla1ha:after{border-color:transparent transparent transparent var(--tooltip-background-color);right:0;top:50%;transform:translate(99%, -50%)}.tooltip.right.svelte-hla1ha{right:0;top:50%;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    )}.tooltip.right.svelte-hla1ha:after{border-color:transparent var(--tooltip-background-color) transparent transparent;left:0;top:50%;transform:translate(-99%, -50%)}.tooltip.animation-fade.svelte-hla1ha{opacity:0;transition:opacity 0.25s ease-in-out}.tooltip.animation-fade.show.svelte-hla1ha{opacity:1}.tooltip.top.animation-slide.svelte-hla1ha{margin-top:10px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.top.animation-slide.show.svelte-hla1ha{margin-top:0;opacity:1}.tooltip.bottom.animation-slide.svelte-hla1ha{margin-bottom:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.bottom.animation-slide.show.svelte-hla1ha{margin-bottom:0;opacity:1}.tooltip.right.animation-slide.svelte-hla1ha{margin-right:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.right.animation-slide.show.svelte-hla1ha{margin-right:0;opacity:1}.tooltip.left.animation-slide.svelte-hla1ha{margin-left:20px;opacity:0;transition:opacity 0.25s ease-in-out, margin 0.25s ease-in-out}.tooltip.left.animation-slide.show.svelte-hla1ha{margin-left:0;opacity:1}.tooltip.left.animation-puff.svelte-hla1ha{filter:blur(2px);opacity:0;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.left.animation-puff.show.svelte-hla1ha{filter:blur(0);opacity:1;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.right.animation-puff.svelte-hla1ha{filter:blur(2px);opacity:0;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.right.animation-puff.show.svelte-hla1ha{filter:blur(0);opacity:1;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.top.animation-puff.svelte-hla1ha{filter:blur(2px);opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.top.animation-puff.show.svelte-hla1ha{filter:blur(0);opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.bottom.animation-puff.svelte-hla1ha{filter:blur(2px);opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(2, 2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out}.tooltip.bottom.animation-puff.show.svelte-hla1ha{filter:blur(0);opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.left.animation-bounce.svelte-hla1ha{opacity:0;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% + var(--tooltip-offset-y))\n    ) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.left.animation-bounce.show.svelte-hla1ha{opacity:1;transform:translate(\n      calc(-100% - var(--tooltip-offset-x)),\n      calc(-50% + var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.right.animation-bounce.svelte-hla1ha{opacity:0;transform:translate(calc(100% + var(--tooltip-offset-x)), calc(-50% + var(--tooltip-offset-y))) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.right.animation-bounce.show.svelte-hla1ha{opacity:1;transform:translate(\n      calc(100% + var(--tooltip-offset-x)),\n      calc(-50% + var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.top.animation-bounce.svelte-hla1ha{opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.top.animation-bounce.show.svelte-hla1ha{opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(-100% - var(--tooltip-offset-y))\n    ) scale(1, 1)}.tooltip.bottom.animation-bounce.svelte-hla1ha{opacity:0;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(1.2, 1.2);transform-origin:50% 50%;transition:opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3)}.tooltip.bottom.animation-bounce.show.svelte-hla1ha{opacity:1;transform:translate(\n      calc(-50% + var(--tooltip-offset-x)),\n      calc(100% + var(--tooltip-offset-y))\n    ) scale(1, 1)}",
  map: "{\"version\":3,\"file\":\"action-tooltip.svelte\",\"sources\":[\"action-tooltip.svelte\"],\"sourcesContent\":[\"<script>\\n  // @ts-check\\n\\n  import { onMount, onDestroy } from 'svelte';\\n  import { computeTooltipPosition, formatVariableKey, getMinWidth, isElementInViewport } from './helpers';\\n  import { inverse } from './constants';\\n\\n  /** @type {HTMLElement | null} */\\n  export let targetElement = null;\\n\\n  /** @type {'hover' | 'click' | 'prop' | string} */\\n  export let action = 'hover';\\n\\n  /** @type {string | {component: any, props?: Record<string, any>}} */\\n  export let content = '';\\n\\n  /** @type {'left' | string} */\\n  export let align = 'left';\\n\\n  /** @type {'top' | string} */\\n  export let position = 'top';\\n\\n  /** @type {number} */\\n  export let maxWidth = 200;\\n\\n  /** @type {Record<string, string> | null} */\\n  export let style = null;\\n\\n  /** @type {string} */\\n  export let theme = '';\\n\\n  /** @type {string} */\\n  export let animation = '';\\n\\n  /** @type {boolean} */\\n  export let arrow = true;\\n\\n  /** @type {boolean} */\\n  export let autoPosition = false;\\n\\n  /** @type {boolean} */\\n  export let show = false;\\n\\n  /** @type {HTMLDivElement | null} */\\n  let tooltipRef = null;\\n\\n  /** @type {number} */\\n  let minWidth = 0;\\n\\n  /** @type {any} */\\n  let component = null;\\n\\n  /** @type {string | null} */\\n  let animationEffect = null;\\n\\n  /** @type {boolean} */\\n  let visible = false;\\n\\n  /** @type {{ bottom: number, top: number, right: number, left: number }} */\\n  let coords = {\\n    bottom: 0,\\n    top: 0,\\n    right: 0,\\n    left: 0\\n  };\\n\\n  const delay = animation ? 200 : 0;\\n\\n  onMount(() => {\\n    if (tooltipRef !== null) {\\n      if (isComponent && !component) {\\n        // @ts-ignore\\n        component = new content.component({ target: tooltipRef, props: { action, ...content.props } });\\n      }\\n\\n      minWidth = getMinWidth(tooltipRef, maxWidth);\\n\\n      if (style && typeof style === 'object') {\\n        for (let prop in style) {\\n          const key = formatVariableKey(prop);\\n          const value = style[prop];\\n\\n          tooltipRef.style.setProperty(`--tooltip-${key}`, value);\\n        }\\n      }\\n    }\\n\\n    // @ts-ignore\\n    if (autoPosition && !isElementInViewport(tooltipRef, targetElement, position)) {\\n      // @ts-ignore\\n      position = inverse[position];\\n    }\\n\\n    coords = computeTooltipPosition(targetElement, tooltipRef, position, coords);\\n\\n    if (animation) {\\n      animationEffect = animation;\\n    }\\n\\n    setTimeout(() => (visible = true), delay);\\n  });\\n\\n  onDestroy(() => {\\n    if (component) {\\n      component.$destroy();\\n      component = null;\\n    }\\n  });\\n\\n  $: isComponent = typeof content === 'object';\\n  $: tooltipRef && show ? setTimeout(() => (visible = true), delay) : (visible = false);\\n</script>\\n\\n{#if content}\\n  <div\\n    bind:this={tooltipRef}\\n    class=\\\"tooltip animation-{animationEffect} {position} {theme}\\\"\\n    class:show={visible}\\n    class:arrowless={!arrow}\\n    style=\\\"bottom: auto; right: auto; left: {coords.left}px; min-width: {minWidth}px; max-width: {maxWidth}px; text-align: {align}; top: {coords.top}px;\\\">\\n    {#if !isComponent}\\n      {@html content}\\n    {/if}\\n  </div>\\n{/if}\\n\\n<style>\\n  /*--------------------------*\\n   * Theme Variables\\n   *--------------------------*/\\n\\n  :root {\\n    --tooltip-arrow-size: 10px;\\n    --tooltip-background-color: rgba(0, 0, 0, 0.9);\\n    --tooltip-border-radius: 4px;\\n    --tooltip-box-shadow: 0 1px 20px rgba(0, 0, 0, 0.25);\\n    --tooltip-font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell,\\n      'Helvetica Neue', sans-serif;\\n    --tooltip-font-size: 14px;\\n    --tooltip-font-weight: 500;\\n    --tooltip-line-height: 1.25rem;\\n    --tooltip-color: #fff;\\n    --tooltip-offset-x: 12px;\\n    --tooltip-offset-y: 12px;\\n    --tooltip-padding: 12px;\\n    --tooltip-pointer-events: none;\\n    --tooltip-white-space-hidden: nowrap;\\n    --tooltip-white-space-shown: normal;\\n    --tooltip-z-index: 100;\\n  }\\n\\n  /*--------------------------*\\n   * Tooltip Styling\\n   *--------------------------*/\\n\\n  .tooltip {\\n    background-color: var(--tooltip-background-color);\\n    box-shadow: var(--tooltip-box-shadow);\\n    border-radius: var(--tooltip-border-radius);\\n    color: var(--tooltip-color);\\n    opacity: 0;\\n    font-family: var(--tooltip-font-family);\\n    font-size: var(--tooltip-font-size);\\n    font-style: normal;\\n    font-weight: var(--tooltip-font-weight);\\n    line-height: var(--tooltip-line-height);\\n    padding: var(--tooltip-padding);\\n    pointer-events: var(---tooltip-pointer-events);\\n    position: absolute;\\n    text-align: left;\\n    visibility: hidden;\\n    white-space: var(--tooltip-white-space-hidden);\\n    z-index: var(--tooltip-z-index);\\n  }\\n\\n  .tooltip.show {\\n    opacity: 1;\\n    visibility: visible;\\n    white-space: var(--tooltip-white-space-shown);\\n  }\\n\\n  .tooltip.bottom:after,\\n  .tooltip.left:after,\\n  .tooltip.right:after,\\n  .tooltip.top:after {\\n    border: var(--tooltip-arrow-size) solid var(--tooltip-background-color);\\n    content: ' ';\\n    position: absolute;\\n  }\\n\\n  .tooltip.arrowless:after {\\n    border: 0 !important;\\n  }\\n\\n  .tooltip.bottom,\\n  .tooltip.top {\\n    --tooltip-offset-x: 0px;\\n    --tooltip-offset-y: 12px;\\n  }\\n\\n  .tooltip.left,\\n  .tooltip.right {\\n    --tooltip-offset-x: 12px;\\n    --tooltip-offset-y: 0px;\\n  }\\n\\n  .tooltip.bottom {\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.bottom:after {\\n    border-color: transparent transparent var(--tooltip-background-color);\\n    left: 50%;\\n    top: 0;\\n    transform: translate(-50%, -99%);\\n  }\\n\\n  .tooltip.top {\\n    left: 50%;\\n    top: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.top:after {\\n    border-color: var(--tooltip-background-color) transparent transparent transparent;\\n    bottom: 0;\\n    left: 50%;\\n    transform: translate(-50%, 99%);\\n  }\\n\\n  .tooltip.left {\\n    left: 0;\\n    top: 50%;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.left:after {\\n    border-color: transparent transparent transparent var(--tooltip-background-color);\\n    right: 0;\\n    top: 50%;\\n    transform: translate(99%, -50%);\\n  }\\n\\n  .tooltip.right {\\n    right: 0;\\n    top: 50%;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    );\\n  }\\n\\n  .tooltip.right:after {\\n    border-color: transparent var(--tooltip-background-color) transparent transparent;\\n    left: 0;\\n    top: 50%;\\n    transform: translate(-99%, -50%);\\n  }\\n\\n  /*--------------------------*\\n   * CSS Animations\\n   *--------------------------*/\\n\\n  /* Fade */\\n\\n  .tooltip.animation-fade {\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.animation-fade.show {\\n    opacity: 1;\\n  }\\n\\n  /* Slide */\\n\\n  .tooltip.top.animation-slide {\\n    margin-top: 10px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-slide.show {\\n    margin-top: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.bottom.animation-slide {\\n    margin-bottom: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-slide.show {\\n    margin-bottom: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.right.animation-slide {\\n    margin-right: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-slide.show {\\n    margin-right: 0;\\n    opacity: 1;\\n  }\\n\\n  .tooltip.left.animation-slide {\\n    margin-left: 20px;\\n    opacity: 0;\\n    transition: opacity 0.25s ease-in-out, margin 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-slide.show {\\n    margin-left: 0;\\n    opacity: 1;\\n  }\\n\\n  /* Puff */\\n\\n  .tooltip.left.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.left.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.right.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.top.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-puff {\\n    filter: blur(2px);\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(2, 2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, filter 0.25s ease-in-out, transform 0.25s ease-in-out;\\n  }\\n\\n  .tooltip.bottom.animation-puff.show {\\n    filter: blur(0);\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  /* Bounce */\\n\\n  .tooltip.left.animation-bounce {\\n    opacity: 0;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% + var(--tooltip-offset-y))\\n    ) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.left.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(-100% - var(--tooltip-offset-x)),\\n      calc(-50% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.right.animation-bounce {\\n    opacity: 0;\\n    transform: translate(calc(100% + var(--tooltip-offset-x)), calc(-50% + var(--tooltip-offset-y))) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.right.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(100% + var(--tooltip-offset-x)),\\n      calc(-50% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.top.animation-bounce {\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.top.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(-100% - var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n\\n  .tooltip.bottom.animation-bounce {\\n    opacity: 0;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(1.2, 1.2);\\n    transform-origin: 50% 50%;\\n    transition: opacity 0.25s ease-in-out, transform 0.25s cubic-bezier(0.5, -1, 0.5, 3);\\n  }\\n\\n  .tooltip.bottom.animation-bounce.show {\\n    opacity: 1;\\n    transform: translate(\\n      calc(-50% + var(--tooltip-offset-x)),\\n      calc(100% + var(--tooltip-offset-y))\\n    ) scale(1, 1);\\n  }\\n</style>\\n\"],\"names\":[],\"mappings\":\"AAmIE,KAAM,CACJ,oBAAoB,CAAE,IAAI,CAC1B,0BAA0B,CAAE,kBAAkB,CAC9C,uBAAuB,CAAE,GAAG,CAC5B,oBAAoB,CAAE,8BAA8B,CACpD,qBAAqB,CAAE;AAC3B,kCAAkC,CAC9B,mBAAmB,CAAE,IAAI,CACzB,qBAAqB,CAAE,GAAG,CAC1B,qBAAqB,CAAE,OAAO,CAC9B,eAAe,CAAE,IAAI,CACrB,kBAAkB,CAAE,IAAI,CACxB,kBAAkB,CAAE,IAAI,CACxB,iBAAiB,CAAE,IAAI,CACvB,wBAAwB,CAAE,IAAI,CAC9B,4BAA4B,CAAE,MAAM,CACpC,2BAA2B,CAAE,MAAM,CACnC,iBAAiB,CAAE,GACrB,CAMA,sBAAS,CACP,gBAAgB,CAAE,IAAI,0BAA0B,CAAC,CACjD,UAAU,CAAE,IAAI,oBAAoB,CAAC,CACrC,aAAa,CAAE,IAAI,uBAAuB,CAAC,CAC3C,KAAK,CAAE,IAAI,eAAe,CAAC,CAC3B,OAAO,CAAE,CAAC,CACV,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,SAAS,CAAE,IAAI,mBAAmB,CAAC,CACnC,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,WAAW,CAAE,IAAI,qBAAqB,CAAC,CACvC,OAAO,CAAE,IAAI,iBAAiB,CAAC,CAC/B,cAAc,CAAE,IAAI,yBAAyB,CAAC,CAC9C,QAAQ,CAAE,QAAQ,CAClB,UAAU,CAAE,IAAI,CAChB,UAAU,CAAE,MAAM,CAClB,WAAW,CAAE,IAAI,4BAA4B,CAAC,CAC9C,OAAO,CAAE,IAAI,iBAAiB,CAChC,CAEA,QAAQ,mBAAM,CACZ,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CACnB,WAAW,CAAE,IAAI,2BAA2B,CAC9C,CAEA,QAAQ,qBAAO,MAAM,CACrB,QAAQ,mBAAK,MAAM,CACnB,QAAQ,oBAAM,MAAM,CACpB,QAAQ,kBAAI,MAAO,CACjB,MAAM,CAAE,IAAI,oBAAoB,CAAC,CAAC,KAAK,CAAC,IAAI,0BAA0B,CAAC,CACvE,OAAO,CAAE,GAAG,CACZ,QAAQ,CAAE,QACZ,CAEA,QAAQ,wBAAU,MAAO,CACvB,MAAM,CAAE,CAAC,CAAC,UACZ,CAEA,QAAQ,qBAAO,CACf,QAAQ,kBAAK,CACX,kBAAkB,CAAE,GAAG,CACvB,kBAAkB,CAAE,IACtB,CAEA,QAAQ,mBAAK,CACb,QAAQ,oBAAO,CACb,kBAAkB,CAAE,IAAI,CACxB,kBAAkB,CAAE,GACtB,CAEA,QAAQ,qBAAQ,CACd,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KACE,CAEA,QAAQ,qBAAO,MAAO,CACpB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACrE,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CACjC,CAEA,QAAQ,kBAAK,CACX,IAAI,CAAE,GAAG,CACT,GAAG,CAAE,CAAC,CACN,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KACE,CAEA,QAAQ,kBAAI,MAAO,CACjB,YAAY,CAAE,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CAAC,WAAW,CACjF,MAAM,CAAE,CAAC,CACT,IAAI,CAAE,GAAG,CACT,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,GAAG,CAChC,CAEA,QAAQ,mBAAM,CACZ,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KACE,CAEA,QAAQ,mBAAK,MAAO,CAClB,YAAY,CAAE,WAAW,CAAC,WAAW,CAAC,WAAW,CAAC,IAAI,0BAA0B,CAAC,CACjF,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,GAAG,CAAC,CAAC,IAAI,CAChC,CAEA,QAAQ,oBAAO,CACb,KAAK,CAAE,CAAC,CACR,GAAG,CAAE,GAAG,CACR,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KACE,CAEA,QAAQ,oBAAM,MAAO,CACnB,YAAY,CAAE,WAAW,CAAC,IAAI,0BAA0B,CAAC,CAAC,WAAW,CAAC,WAAW,CACjF,IAAI,CAAE,CAAC,CACP,GAAG,CAAE,GAAG,CACR,SAAS,CAAE,UAAU,IAAI,CAAC,CAAC,IAAI,CACjC,CAQA,QAAQ,6BAAgB,CACtB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAC5B,CAEA,QAAQ,eAAe,mBAAM,CAC3B,OAAO,CAAE,CACX,CAIA,QAAQ,IAAI,8BAAiB,CAC3B,UAAU,CAAE,IAAI,CAChB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,IAAI,gBAAgB,mBAAM,CAChC,UAAU,CAAE,CAAC,CACb,OAAO,CAAE,CACX,CAEA,QAAQ,OAAO,8BAAiB,CAC9B,aAAa,CAAE,IAAI,CACnB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,OAAO,gBAAgB,mBAAM,CACnC,aAAa,CAAE,CAAC,CAChB,OAAO,CAAE,CACX,CAEA,QAAQ,MAAM,8BAAiB,CAC7B,YAAY,CAAE,IAAI,CAClB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,MAAM,gBAAgB,mBAAM,CAClC,YAAY,CAAE,CAAC,CACf,OAAO,CAAE,CACX,CAEA,QAAQ,KAAK,8BAAiB,CAC5B,WAAW,CAAE,IAAI,CACjB,OAAO,CAAE,CAAC,CACV,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WACtD,CAEA,QAAQ,KAAK,gBAAgB,mBAAM,CACjC,WAAW,CAAE,CAAC,CACd,OAAO,CAAE,CACX,CAIA,QAAQ,KAAK,6BAAgB,CAC3B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,KAAK,eAAe,mBAAM,CAChC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,MAAM,6BAAgB,CAC5B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,MAAM,eAAe,mBAAM,CACjC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,IAAI,6BAAgB,CAC1B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,IAAI,eAAe,mBAAM,CAC/B,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,OAAO,6BAAgB,CAC7B,MAAM,CAAE,KAAK,GAAG,CAAC,CACjB,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CAAC,CACb,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,MAAM,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,WACnF,CAEA,QAAQ,OAAO,eAAe,mBAAM,CAClC,MAAM,CAAE,KAAK,CAAC,CAAC,CACf,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAIA,QAAQ,KAAK,+BAAkB,CAC7B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjB,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,KAAK,iBAAiB,mBAAM,CAClC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC5C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,MAAM,+BAAkB,CAC9B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE,UAAU,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CAChH,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,MAAM,iBAAiB,mBAAM,CACnC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,IAAI,+BAAkB,CAC5B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjB,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,IAAI,iBAAiB,mBAAM,CACjC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,KAAK,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC3C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd,CAEA,QAAQ,OAAO,+BAAkB,CAC/B,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,GAAG,CAAC,CAAC,GAAG,CAAC,CACjB,gBAAgB,CAAE,GAAG,CAAC,GAAG,CACzB,UAAU,CAAE,OAAO,CAAC,KAAK,CAAC,WAAW,CAAC,CAAC,SAAS,CAAC,KAAK,CAAC,aAAa,GAAG,CAAC,CAAC,EAAE,CAAC,CAAC,GAAG,CAAC,CAAC,CAAC,CACrF,CAEA,QAAQ,OAAO,iBAAiB,mBAAM,CACpC,OAAO,CAAE,CAAC,CACV,SAAS,CAAE;AACf,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC,CAAC;AAC3C,MAAM,KAAK,IAAI,CAAC,CAAC,CAAC,IAAI,kBAAkB,CAAC,CAAC;AAC1C,KAAK,CAAC,MAAM,CAAC,CAAC,CAAC,CAAC,CACd\"}"
};
var Action_tooltip = create_ssr_component(function ($$result, $$props, $$bindings, slots) {
  var isComponent;
  var _$$props$targetElemen = $$props.targetElement,
    targetElement = _$$props$targetElemen === void 0 ? null : _$$props$targetElemen;
  var _$$props$action = $$props.action,
    action = _$$props$action === void 0 ? 'hover' : _$$props$action;
  var _$$props$content = $$props.content,
    content = _$$props$content === void 0 ? '' : _$$props$content;
  var _$$props$align = $$props.align,
    align = _$$props$align === void 0 ? 'left' : _$$props$align;
  var _$$props$position = $$props.position,
    position = _$$props$position === void 0 ? 'top' : _$$props$position;
  var _$$props$maxWidth = $$props.maxWidth,
    maxWidth = _$$props$maxWidth === void 0 ? 200 : _$$props$maxWidth;
  var _$$props$style = $$props.style,
    style = _$$props$style === void 0 ? null : _$$props$style;
  var _$$props$theme = $$props.theme,
    theme = _$$props$theme === void 0 ? '' : _$$props$theme;
  var _$$props$animation = $$props.animation,
    animation = _$$props$animation === void 0 ? '' : _$$props$animation;
  var _$$props$arrow = $$props.arrow,
    arrow = _$$props$arrow === void 0 ? true : _$$props$arrow;
  var _$$props$autoPosition = $$props.autoPosition,
    autoPosition = _$$props$autoPosition === void 0 ? false : _$$props$autoPosition;
  var _$$props$show = $$props.show,
    show = _$$props$show === void 0 ? false : _$$props$show;

  /** @type {HTMLDivElement | null} */
  var tooltipRef = null;

  /** @type {number} */
  var minWidth = 0;

  /** @type {string | null} */
  var animationEffect = null;

  /** @type {boolean} */
  var visible = false;

  /** @type {{ bottom: number, top: number, right: number, left: number }} */
  var coords = {
    bottom: 0,
    top: 0,
    right: 0,
    left: 0
  };
  var delay = animation ? 200 : 0;
  onMount(function () {

    // @ts-ignore
    if (autoPosition && !isElementInViewport(tooltipRef, targetElement, position)) {
      // @ts-ignore
      position = inverse[position];
    }
    coords = computeTooltipPosition(targetElement, tooltipRef, position, coords);
    if (animation) {
      animationEffect = animation;
    }
    setTimeout(function () {
      return visible = true;
    }, delay);
  });
  onDestroy(function () {
  });
  if ($$props.targetElement === void 0 && $$bindings.targetElement && targetElement !== void 0) $$bindings.targetElement(targetElement);
  if ($$props.action === void 0 && $$bindings.action && action !== void 0) $$bindings.action(action);
  if ($$props.content === void 0 && $$bindings.content && content !== void 0) $$bindings.content(content);
  if ($$props.align === void 0 && $$bindings.align && align !== void 0) $$bindings.align(align);
  if ($$props.position === void 0 && $$bindings.position && position !== void 0) $$bindings.position(position);
  if ($$props.maxWidth === void 0 && $$bindings.maxWidth && maxWidth !== void 0) $$bindings.maxWidth(maxWidth);
  if ($$props.style === void 0 && $$bindings.style && style !== void 0) $$bindings.style(style);
  if ($$props.theme === void 0 && $$bindings.theme && theme !== void 0) $$bindings.theme(theme);
  if ($$props.animation === void 0 && $$bindings.animation && animation !== void 0) $$bindings.animation(animation);
  if ($$props.arrow === void 0 && $$bindings.arrow && arrow !== void 0) $$bindings.arrow(arrow);
  if ($$props.autoPosition === void 0 && $$bindings.autoPosition && autoPosition !== void 0) $$bindings.autoPosition(autoPosition);
  if ($$props.show === void 0 && $$bindings.show && show !== void 0) $$bindings.show(show);
  $$result.css.add(css);
  isComponent = _typeof(content) === 'object';
  {
    visible = false;
  }
  return "".concat(content ? "<div class=\"".concat(["tooltip animation-" + escape(animationEffect, true) + " " + escape(position, true) + " " + escape(theme, true) + " svelte-hla1ha", (visible ? "show" : "") + ' ' + (!arrow ? "arrowless" : "")].join(' ').trim(), "\" style=\"").concat("bottom: auto; right: auto; left: " + escape(coords.left, true) + "px; min-width: " + escape(minWidth, true) + "px; max-width: " + escape(maxWidth, true) + "px; text-align: " + escape(align, true) + "; top: " + escape(coords.top, true) + "px;", "\"").concat(add_attribute("this", tooltipRef, 0), ">").concat(!isComponent ? "".concat(content) : "", "</div>") : "");
});
var Tooltip = Action_tooltip;

var tooltip = function tooltip(element, props) {
  var component = null;
  var title = element.getAttribute('title');
  var action = (props === null || props === void 0 ? void 0 : props.action) || element.getAttribute('action') || 'hover';
  var config = _objectSpread2(_objectSpread2({}, props), {}, {
    targetElement: element
  });
  if (title) {
    element.removeAttribute('title');
    config.content = title;
  }
  var onClick = function onClick() {
    if (component) {
      onHide();
    } else {
      onShow();
    }
  };
  var onShow = function onShow() {
    if (!component) {
      component = new Tooltip({
        target: element,
        props: config
      });
    }
  };
  var onHide = function onHide() {
    if (component) {
      component.$destroy();
      component = null;
    }
  };
  var addListeners = function addListeners() {
    if (element !== null) {
      removeListeners();
      if (config.show) {
        onShow();
      }
      if (action === 'click') {
        element.addEventListener('click', onClick);
      }
      if (action === 'hover') {
        element.addEventListener('mouseenter', onShow);
        element.addEventListener('mouseleave', onHide);
      }
    }
  };
  var removeListeners = function removeListeners() {
    if (element !== null) {
      element.removeEventListener('click', onClick);
      element.removeEventListener('mouseenter', onShow);
      element.removeEventListener('mouseleave', onHide);
    }
  };
  addListeners();
  return {
    destroy: function destroy() {
      removeListeners();
      if (title) {
        element.setAttribute('title', title);
      }
    }
  };
};

export { Tooltip$2 as Tooltip, tooltip };
